ServerFnError

Enum ServerFnError 

pub enum ServerFnError<E = NoCustomError> {
    WrappedServerError(E),
    Registration(String),
    Request(String),
    Response(String),
    ServerError(String),
    MiddlewareError(String),
    Deserialization(String),
    Serialization(String),
    Args(String),
    MissingArg(String),
}
A type that can be used as the return type of the server function for easy error conversion with ? operator. This type can be replaced with any other error type that implements FromServerFnError.

Unlike ServerFnErrorErr, this does not implement Error. This means that other error types can easily be converted into it using the ? operator.

Variants



WrappedServerError(E)

๐Ÿ‘ŽDeprecated since 0.8.0:

Now server_fn can return any error type other than ServerFnError, so users should place their custom error type instead of ServerFnError

A user-defined custom error type, which defaults to NoCustomError.



Registration(String)

Error while trying to register the server function (only occurs in case of poisoned RwLock).



Request(String)

Occurs on the client if there is a network error while trying to run function on server.



Response(String)

Occurs on the server if there is an error creating an HTTP response.



ServerError(String)

Occurs when there is an error while actually running the function on the server.



MiddlewareError(String)

Occurs when there is an error while actually running the middleware on the server.



Deserialization(String)

Occurs on the client if there is an error deserializing the serverโ€™s response.



Serialization(String)

Occurs on the client if there is an error serializing the server function arguments.



Args(String)

Occurs on the server if there is an error deserializing one of the arguments thatโ€™s been sent.



MissingArg(String)

Occurs on the server if thereโ€™s a missing argument.

Implementations



impl ServerFnError

pub fn new(msg: impl ToString) -> ServerFnError

Constructs a new ServerFnError::ServerError from some other type.