Function create_rw_signal
pub fn create_rw_signal<T>(value: T) -> RwSignal<T>👎Deprecated:
This function is being removed to conform to Rust idioms. Please use RwSignal::new() instead.
Creates a reactive signal with the getter and setter unified in one value.