Struct ArcRwSignal
pub struct ArcRwSignal<T> {
pub(crate) value: Arc<RwLock<T>>,
pub(crate) inner: Arc<RwLock<SubscriberSet>>,
}Expand description
A reference-counted signal that can be read from or written to.
A signal is a piece of data that may change over time, and notifies other code when it has changed. This is the atomic unit of reactivity, which begins all other processes of reactive updates.
This is a reference-counted signal, which is Clone but not Copy.
For arena-allocated Copy signals, use RwSignal.
Core Trait Implementations
Reading the Value
.get()clones the current value of the signal. If you call it within an effect, it will cause that effect to subscribe to the signal, and to re-run whenever the value of the signal changes..get_untracked()clones the value of the signal without reactively tracking it.
.read()returns a guard that allows accessing the value of the signal by reference. If you call it within an effect, it will cause that effect to subscribe to the signal, and to re-run whenever the value of the signal changes..read_untracked()gives access to the current value of the signal without reactively tracking it.
.with()allows you to reactively access the signal’s value without cloning by applying a callback function..with_untracked()allows you to access the signal’s value by applying a callback function without reactively tracking it.
.to_stream()converts the signal to anasyncstream of values.
Updating the Value
.set()sets the signal to a new value..update()updates the value of the signal by applying a closure that takes a mutable reference..write()returns a guard through which the signal can be mutated, and which notifies subscribers when it is dropped.
Each of these has a related
_untracked()method, which updates the signal without notifying subscribers. Untracked updates are not desirable in most cases, as they cause “tearing” between the signal’s value and its observed value. If you want a non-reactive container, usedArenaIteminstead.
Examples
let count = ArcRwSignal::new(0);
// ✅ calling the getter clones and returns the value
// this can be `count()` on nightly
assert_eq!(count.get(), 0);
// ✅ calling the setter sets the value
// this can be `set_count(1)` on nightly
count.set(1);
assert_eq!(count.get(), 1);
// ❌ you could call the getter within the setter
// set_count.set(count.get() + 1);
// ✅ however it's more efficient to use .update() and mutate the value in place
count.update(|count: &mut i32| *count += 1);
assert_eq!(count.get(), 2);
// ✅ you can create "derived signals" with a Fn() -> T interface
let double_count = {
// clone before moving into the closure because we use it below
let count = count.clone();
move || count.get() * 2
};
count.set(0);
assert_eq!(double_count(), 0);
count.set(1);
assert_eq!(double_count(), 2);Fields
value: Arc<RwLock<T>>inner: Arc<RwLock<SubscriberSet>>Implementations
impl<T> ArcRwSignal<T>
impl<T> ArcRwSignal<T>
pub fn new(value: T) -> ArcRwSignal<T>
pub fn new(value: T) -> ArcRwSignal<T>
Creates a new signal, taking the initial value as its argument.
pub fn read_only(&self) -> ArcReadSignal<T>
pub fn read_only(&self) -> ArcReadSignal<T>
Returns a read-only handle to the signal.
pub fn write_only(&self) -> ArcWriteSignal<T>
pub fn write_only(&self) -> ArcWriteSignal<T>
Returns a write-only handle to the signal.
pub fn split(&self) -> (ArcReadSignal<T>, ArcWriteSignal<T>)
pub fn split(&self) -> (ArcReadSignal<T>, ArcWriteSignal<T>)
Splits the signal into its readable and writable halves.
pub fn unite(
read: ArcReadSignal<T>,
write: ArcWriteSignal<T>,
) -> Option<ArcRwSignal<T>>
pub fn unite( read: ArcReadSignal<T>, write: ArcWriteSignal<T>, ) -> Option<ArcRwSignal<T>>
Reunites the two halves of a signal. Returns None if the two signals
provided were not created from the same signal.