Struct ArcSubmission
pub struct ArcSubmission<I, O> {
input: ArcRwSignal<Option<I>>,
value: ArcRwSignal<Option<O>>,
pending: ArcRwSignal<bool>,
canceled: ArcRwSignal<bool>,
}Expand description
An action that has been submitted by dispatching it to a MultiAction.
Fields
input: ArcRwSignal<Option<I>>value: ArcRwSignal<Option<O>>pending: ArcRwSignal<bool>canceled: ArcRwSignal<bool>Implementations
impl<I, O> ArcSubmission<I, O>where
I: 'static,
O: 'static,
impl<I, O> ArcSubmission<I, O>where
I: 'static,
O: 'static,
pub fn input(&self) -> ArcReadSignal<Option<I>>
pub fn input(&self) -> ArcReadSignal<Option<I>>
The current argument that was dispatched to the async function.
Some while we are waiting for it to resolve, None if it has resolved.
pub fn value(&self) -> ArcReadSignal<Option<O>>
pub fn value(&self) -> ArcReadSignal<Option<O>>
The most recent return value of the async function.
pub fn pending(&self) -> ArcReadSignal<bool>
pub fn pending(&self) -> ArcReadSignal<bool>
Whether this submision is still waiting to resolve.
pub fn canceled(&self) -> ArcReadSignal<bool>
pub fn canceled(&self) -> ArcReadSignal<bool>
Whether this submission has been canceled.
pub fn cancel(&self)
pub fn cancel(&self)
Cancels the submission. This will not necessarily prevent the Future
from continuing to run, but it will update the returned value.