Enum MaybeSignal
pub enum MaybeSignal<T, S = SyncStorage>where
T: 'static,
S: Storage<T>,{
Static(T),
Dynamic(Signal<T, S>),
}๐Deprecated since 0.7.0-rc3:
MaybeSignal<T> is deprecated in favour of Signal<T> which is Copy, now has a more efficient From<T> implementation and other benefits in 0.7.Expand description
A wrapper for a value that is either T or Signal<T>.
This allows you to create APIs that take either a reactive or a non-reactive value of the same type. This is especially useful for component properties.
let (count, set_count) = signal(2);
let double_count = MaybeSignal::derive(move || count.get() * 2);
let memoized_double_count = Memo::new(move |_| count.get() * 2);
let static_value = 5;
// this function takes either a reactive or non-reactive value
fn above_3(arg: &MaybeSignal<i32>) -> bool {
// โ
calling the signal clones and returns the value
// it is a shorthand for arg.get()
arg.get() > 3
}
assert_eq!(above_3(&static_value.into()), true);
assert_eq!(above_3(&count.into()), false);
assert_eq!(above_3(&double_count), true);
assert_eq!(above_3(&memoized_double_count.into()), true);Variants
Static(T)
๐Deprecated since 0.7.0-rc3:
MaybeSignal<T> is deprecated in favour of Signal<T> which is Copy, now has a more efficient From<T> implementation and other benefits in 0.7.An unchanging value of type T.
Dynamic(Signal<T, S>)
๐Deprecated since 0.7.0-rc3:
MaybeSignal<T> is deprecated in favour of Signal<T> which is Copy, now has a more efficient From<T> implementation and other benefits in 0.7.A reactive signal that contains a value of type T.
Implementations
impl<T> MaybeSignal<T>
impl<T> MaybeSignal<T>
pub fn derive(
derived_signal: impl Fn() -> T + Send + Sync + 'static,
) -> MaybeSignal<T>
pub fn derive( derived_signal: impl Fn() -> T + Send + Sync + 'static, ) -> MaybeSignal<T>
Wraps a derived signal, i.e., any computation that accesses one or more reactive signals.
impl<T> MaybeSignal<T, LocalStorage>
impl<T> MaybeSignal<T, LocalStorage>
pub fn derive_local(
derived_signal: impl Fn() -> T + 'static,
) -> MaybeSignal<T, LocalStorage>
pub fn derive_local( derived_signal: impl Fn() -> T + 'static, ) -> MaybeSignal<T, LocalStorage>
Wraps a derived signal, i.e., any computation that accesses one or more reactive signals.